sub five {
    5
}
my $x = "Something simple to demo 'deparse'";
my $y = five();
print $y;
